==> HDExport2_src2.00.zip: config.h <==
///////////////////////////////////////////////////////////////////////////
// HD_export2
///////////////////////////////////////////////////////////////////////////
// 16/04/2002
//
// Copyright (c) 2002-2003, E. Ravon (Bat)
///////////////////////////////////////////////////////////////////////////

// Version
#define _VERSION_ 2
#define _SVERSION_ 0

// Cl en BDR
#define _CLE "Software\\HD_Export"

//Fichier d'export
#define FIC_EXPORT_AGENDA 			"agenda.exp.txt"
#define FIC_EXPORT_AGENDA_PALM 		"agenda.dba"
#define FIC_EXPORT_AGENDA_PSION 	"HD_AG_UP.X"
#define FIC_IMPORT_AGENDA_PSION 	"HD_AG_DN.X"

// Mode de fonctionnement
#define MODE_NORMAL		0		// Fonctionnement normal
#define MODE_AUTO_TXT	1		// Export automatique au dmarrage en texte
#define MODE_AUTO_PALM	2		// Export automatique au dmarrage en foramt palm
#define MODE_AUTO_PSION	3		// Export automatique au dmarrage en foramt psion

// Taille maximale
#define MAX_LISTE		1000

// Donnes
typedef struct{
	char path[MAX_PATH];		//	Chemin HD (ex "C:\HelloDOC")
	char cabinet[MAX_PATH];		//	Cabinet HD (ex : "Demo")
	char user[MAX_PATH];		//  Utilisateur HD (ex : "Dr Marceau")
	char password[MAX_PATH];	//  Password (non sauvegard)
	int mode;					//  Mode de fonctionnement (une des constante indiquant le mode de fonctionnement)
	int version;				//  N de version
	int sversion;				//  N de sous-version
	char liste_patient[MAX_LISTE];			//  Liste des patients  exporter
	int use_patient;			//  Export uniquement des patients de la liste
	int use_visite;				//  Export uniquement des visites
	int today_only;				//  Export uniquement pour le jour actuel
	int palm_group;				//  Met le commentaire avec le Nom du patient
	int increment_agenda;		//  Nb de min d'un rendez vous
	// Export PALM
	char path_datebook[MAX_PATH];// Si ce champ est renseign, on prend ce fichier, sinon le choix est laiss
								 //  l'utilisateur
	}CONFIG;
extern CONFIG config;			// Accs depuis les autres fichiers  la configuration


// Fonctions
void lit_config(void);				// Lit la configuration	en BDR (Base De Registre)
void ecrit_config(void);			// Ecrit la configuration en BDR
void process_cmd_line(char *txt);	// "parse" la ligne de commande
BOOL ouvre_fichier(HWND hwnd,char *sortie,int taille_buffer,char *filtre,char *titre);
									// boite d'ouverture d'un fichier

==> HDExport2_src3.0.zip: config.h <==
///////////////////////////////////////////////////////////////////////////
// HD_export2
///////////////////////////////////////////////////////////////////////////
// 16/04/2002
//
// Copyright (c) 2002-2003, E. Ravon (Bat)
///////////////////////////////////////////////////////////////////////////

// Version
#define _VERSION_ 3
#define _SVERSION_ 0

// Cl en BDR
#define _CLE "Software\\HD_Export"

//Fichier d'export
#define FIC_EXPORT_AGENDA 			"agenda.exp.txt"
#define FIC_EXPORT_AGENDA_CSV 		"agenda.exp.csv"
#define FIC_EXPORT_AGENDA_PALM 		"agenda.dba"
#define FIC_EXPORT_AGENDA_PSION 	"HD_AG_UP.X"
#define FIC_IMPORT_AGENDA_PSION 	"HD_AG_DN.X"

// Mode de fonctionnement
#define MODE_NORMAL		0		// Fonctionnement normal
#define MODE_AUTO_TXT	1		// Export automatique au dmarrage en texte
#define MODE_AUTO_PALM	2		// Export automatique au dmarrage en foramt palm
#define MODE_AUTO_PSION	3		// Export automatique au dmarrage en foramt psion
#define MODE_AUTO_CSV	4		// Export automatique au dmarrage en texte

// Taille maximale
#define MAX_LISTE		1000

// Donnes
typedef struct{
	char path[MAX_PATH];		//	Chemin HD (ex "C:\HelloDOC")
	char cabinet[MAX_PATH];		//	Cabinet HD (ex : "Demo")
	char user[MAX_PATH];		//  Utilisateur HD (ex : "Dr Marceau")
	char password[MAX_PATH];	//  Password (non sauvegard)
	int mode;					//  Mode de fonctionnement (une des constante indiquant le mode de fonctionnement)
	int version;				//  N de version
	int sversion;				//  N de sous-version
	char liste_patient[MAX_LISTE];			//  Liste des patients  exporter
	int use_patient;			//  Export uniquement des patients de la liste
	int use_visite;				//  Export uniquement des visites
	int today_only;				//  Exporte uniquement pour le jour actuel
	int export_all;			    //  Exporte aussi les donnes passes (toutes)
	int palm_group;				//  Met le commentaire avec le Nom du patient
	int increment_agenda;		//  Nb de min d'un rendez vous
	// Export PALM
	char path_datebook[MAX_PATH];// Si ce champ est renseign, on prend ce fichier, sinon le choix est laiss
								 //  l'utilisateur
	}CONFIG;
extern CONFIG config;			// Accs depuis les autres fichiers  la configuration


// Fonctions
void lit_config(void);				// Lit la configuration	en BDR (Base De Registre)
void ecrit_config(void);			// Ecrit la configuration en BDR
void process_cmd_line(char *txt);	// "parse" la ligne de commande
BOOL ouvre_fichier(HWND hwnd,char *sortie,int taille_buffer,char *filtre,char *titre);
									// boite d'ouverture d'un fichier
